@@ -1,5 +1,6 @@
 var NAVTREEINDEX18 =
 {
+"structpw__impl__link__events.html":[8,4,4,1],
 "structpw__impl__link__events.html#a05b20c99f1014e62e0d032b92382f584":[8,4,4,1,5],
 "structpw__impl__link__events.html#a05c9fec1c6580f673d09e33005bca5ee":[8,4,4,1,0],
 "structpw__impl__link__events.html#a36d3179004ca94bfe99cfc7c7608321a":[8,4,4,1,4],
@@ -248,6 +249,5 @@ var NAVTREEINDEX18 =
 "structpw__protocol__server.html#a0b93bd3cd5a2680d8ece4796826406fc":[8,4,13,2,1],
 "structpw__protocol__server.html#acc7b1e9530a048b084976fc647ab446f":[8,4,13,2,4],
 "structpw__protocol__server.html#ae953d4026c613d91a0cb34398d3f4367":[8,4,13,2,2],
-"structpw__proxy.html":[8,3,13,2],
-"structpw__proxy__events.html":[8,3,13,1]
+"structpw__proxy.html":[8,3,13,2]
 };
