@@ -1,5 +1,6 @@
 var NAVTREEINDEX21 =
 {
+"structspa__loop__control__hooks.html#a94545cf994d47a1acc84437e5c357141":[8,7,9,4,6,2],
 "structspa__loop__control__methods.html":[8,7,9,4,7],
 "structspa__loop__control__methods.html#a2673d98892466d81baea852c94c91a39":[8,7,9,4,7,1],
 "structspa__loop__control__methods.html#a2d30cbd197ae33a77b5ccce2216ca61a":[8,7,9,4,7,5],
@@ -248,6 +249,5 @@ var NAVTREEINDEX21 =
 "structspa__ratelimit.html#af29b16a4c28de3a2503ae1302dba9ff7":[9,0,280,2],
 "structspa__ratelimit.html#af383ccf1d089eadee60b0259afc329ab":[9,0,280,3],
 "structspa__rectangle.html":[8,7,8,1,1],
-"structspa__rectangle.html#a6104eab08e11a0f5f658a5ffd1878068":[8,7,8,1,1,0],
-"structspa__rectangle.html#a7510157f1ac054a3dc70c0c6d49083ad":[8,7,8,1,1,1]
+"structspa__rectangle.html#a6104eab08e11a0f5f658a5ffd1878068":[8,7,8,1,1,0]
 };
